local EasyMCM = include("easyMCM.EasyMCM")

-- Create a placeholder page if EasyMCM is not installed.
if (EasyMCM == nil) or (EasyMCM.version < 1.4) then
    local function placeholderMCM(element)
        element:createLabel{text="This mod config menu requires EasyMCM v1.4 or later."}
        local link = element:createTextSelect{text="Go to EasyMCM Nexus Page"}
        link.color = tes3ui.getPalette("link_color")
        link.widget.idle = tes3ui.getPalette("link_color")
        link.widget.over = tes3ui.getPalette("link_over_color")
        link.widget.pressed = tes3ui.getPalette("link_pressed_color")
        link:register("mouseClick", function()
            os.execute("start https://www.nexusmods.com/morrowind/mods/46427?tab=files")
        end)
    end
    mwse.registerModConfig("Ressources communes de Tamriel", {onCreate=placeholderMCM})
    return
end

local config = require("tamrielData.config")

----------------------
-- EasyMCM Template --
----------------------
local template = EasyMCM.createTemplate{name="Ressources communes de Tamriel"}
template:saveOnClose("tamrielData", config)
template:register()

-- Preferences Page
local preferences = template:createSideBarPage{label="Prfrences"}
preferences.sidebar:createInfo{text="Ressources communes de Tamriel MWSE-Lua v1.1"}

-- Sidebar Credits
local credits = preferences.sidebar:createCategory{label="Credits:"}
credits:createHyperlink{
    text = "mort - Scripting",
    exec = "start https://www.nexusmods.com/morrowind/users/4138441/?tab=user+files",
}
credits:createHyperlink{
    text = "Kynesifnar - Scripting",
    exec = "start https://www.nexusmods.com/users/56893332?tab=user+files",
}
credits:createHyperlink{
    text = "chef - Gestion de TD_addon",
    exec = "start https://github.com/cheflul/Chefmod",
}
credits:createHyperlink{
    text = "Cicero - Icnes",
    exec = "start https://www.nexusmods.com/morrowind/users/64610026?tab=user+files",
}
credits:createHyperlink{
    text = "Greatness7 - Modle de MCM",
    exec = "start https://www.nexusmods.com/morrowind/users/64030?tab=user+files",
}
credits:createHyperlink{
    text = "NullCascade - Support de MWSE",
    exec = "start https://www.nexusmods.com/morrowind/users/26153919?tab=user+files",
}

-- Feature Toggles
local toggles = preferences:createCategory{label="Fonctionnalits"}
toggles:createOnOffButton{
    label = "Ajout de nouveaux sorts d'Invocation",
    description = "Ajoute de nouveaux sorts d'Invocation utilisant des cratures de Ressources communes de Tamriel cres pour Tamriel Rebuilt, Project: Cyrodiil et Skyrim: Home of the Nords.\nRequiert un rechargement.\n\nPar dfaut : activ\n\n",
    variable = EasyMCM:createTableVariable{
        id = "summoningSpells",
        table = config,
    },
}

toggles:createOnOffButton{
    label = "Dsactiver la vrification des BSAs",
    description = "Ignore la vrification des BSAs. Ne corrige pas les erreurs lies aux fichiers BSAs, ne fait que dsactiver l'avertissement.\n\nPar dfaut : dsactiv\n\n",
    variable = EasyMCM:createTableVariable{
        id = "skipBSAChecks",
        table = config,
    },
}

toggles:createOnOffButton{
    label = "Corriger les animations du joueur pour les nouvelles races",
    description = "Corrige les animations lorsque vous jouez un Khajiit Ohmes-raht ou Suthay via un plugin tiers\nRequiert un rechargement. Votre queue peut disparatre jusqu'au rechargement quand des animations d'autres addons MWSE sont appliques au joueur.\nSi vous utilisez un replacer d'animations qui ajoute des os pour la queue au fichier base_anim.nif, cette fonctionnalit ne sera probablement pas ncessaire.\n\nPar dfaut : activ\n\n",
    variable = EasyMCM:createTableVariable{
        id = "fixPlayerRaceAnimations",
        table = config,
    },
}
